Documentation
¶
Index ¶
- type IngressControllerMock
- func (mock *IngressControllerMock) AddClusterScopedHandler(ctx context.Context, name string, clusterName string, ...)
- func (mock *IngressControllerMock) AddClusterScopedHandlerCalls() []struct{ ... }
- func (mock *IngressControllerMock) AddHandler(ctx context.Context, name string, handler v1beta1a.IngressHandlerFunc)
- func (mock *IngressControllerMock) AddHandlerCalls() []struct{ ... }
- func (mock *IngressControllerMock) Enqueue(namespace string, name string)
- func (mock *IngressControllerMock) EnqueueCalls() []struct{ ... }
- func (mock *IngressControllerMock) Generic() controller.GenericController
- func (mock *IngressControllerMock) GenericCalls() []struct{}
- func (mock *IngressControllerMock) Informer() cache.SharedIndexInformer
- func (mock *IngressControllerMock) InformerCalls() []struct{}
- func (mock *IngressControllerMock) Lister() v1beta1a.IngressLister
- func (mock *IngressControllerMock) ListerCalls() []struct{}
- func (mock *IngressControllerMock) Start(ctx context.Context, threadiness int) error
- func (mock *IngressControllerMock) StartCalls() []struct{ ... }
- func (mock *IngressControllerMock) Sync(ctx context.Context) error
- func (mock *IngressControllerMock) SyncCalls() []struct{ ... }
- type IngressInterfaceMock
- func (mock *IngressInterfaceMock) AddClusterScopedHandler(ctx context.Context, name string, clusterName string, ...)
- func (mock *IngressInterfaceMock) AddClusterScopedHandlerCalls() []struct{ ... }
- func (mock *IngressInterfaceMock) AddClusterScopedLifecycle(ctx context.Context, name string, clusterName string, ...)
- func (mock *IngressInterfaceMock) AddClusterScopedLifecycleCalls() []struct{ ... }
- func (mock *IngressInterfaceMock) AddHandler(ctx context.Context, name string, sync v1beta1a.IngressHandlerFunc)
- func (mock *IngressInterfaceMock) AddHandlerCalls() []struct{ ... }
- func (mock *IngressInterfaceMock) AddLifecycle(ctx context.Context, name string, lifecycle v1beta1a.IngressLifecycle)
- func (mock *IngressInterfaceMock) AddLifecycleCalls() []struct{ ... }
- func (mock *IngressInterfaceMock) Controller() v1beta1a.IngressController
- func (mock *IngressInterfaceMock) ControllerCalls() []struct{}
- func (mock *IngressInterfaceMock) Create(in1 *v1beta1.Ingress) (*v1beta1.Ingress, error)
- func (mock *IngressInterfaceMock) CreateCalls() []struct{ ... }
- func (mock *IngressInterfaceMock) Delete(name string, options *v1.DeleteOptions) error
- func (mock *IngressInterfaceMock) DeleteCalls() []struct{ ... }
- func (mock *IngressInterfaceMock) DeleteCollection(deleteOpts *v1.DeleteOptions, listOpts v1.ListOptions) error
- func (mock *IngressInterfaceMock) DeleteCollectionCalls() []struct{ ... }
- func (mock *IngressInterfaceMock) DeleteNamespaced(namespace string, name string, options *v1.DeleteOptions) error
- func (mock *IngressInterfaceMock) DeleteNamespacedCalls() []struct{ ... }
- func (mock *IngressInterfaceMock) Get(name string, opts v1.GetOptions) (*v1beta1.Ingress, error)
- func (mock *IngressInterfaceMock) GetCalls() []struct{ ... }
- func (mock *IngressInterfaceMock) GetNamespaced(namespace string, name string, opts v1.GetOptions) (*v1beta1.Ingress, error)
- func (mock *IngressInterfaceMock) GetNamespacedCalls() []struct{ ... }
- func (mock *IngressInterfaceMock) List(opts v1.ListOptions) (*v1beta1a.IngressList, error)
- func (mock *IngressInterfaceMock) ListCalls() []struct{ ... }
- func (mock *IngressInterfaceMock) ObjectClient() *objectclient.ObjectClient
- func (mock *IngressInterfaceMock) ObjectClientCalls() []struct{}
- func (mock *IngressInterfaceMock) Update(in1 *v1beta1.Ingress) (*v1beta1.Ingress, error)
- func (mock *IngressInterfaceMock) UpdateCalls() []struct{ ... }
- func (mock *IngressInterfaceMock) Watch(opts v1.ListOptions) (watch.Interface, error)
- func (mock *IngressInterfaceMock) WatchCalls() []struct{ ... }
- type IngressListerMock
- func (mock *IngressListerMock) Get(namespace string, name string) (*v1beta1.Ingress, error)
- func (mock *IngressListerMock) GetCalls() []struct{ ... }
- func (mock *IngressListerMock) List(namespace string, selector labels.Selector) ([]*v1beta1.Ingress, error)
- func (mock *IngressListerMock) ListCalls() []struct{ ... }
- type IngressesGetterMock
- type PodSecurityPoliciesGetterMock
- type PodSecurityPolicyControllerMock
- func (mock *PodSecurityPolicyControllerMock) AddClusterScopedHandler(ctx context.Context, name string, clusterName string, ...)
- func (mock *PodSecurityPolicyControllerMock) AddClusterScopedHandlerCalls() []struct{ ... }
- func (mock *PodSecurityPolicyControllerMock) AddHandler(ctx context.Context, name string, ...)
- func (mock *PodSecurityPolicyControllerMock) AddHandlerCalls() []struct{ ... }
- func (mock *PodSecurityPolicyControllerMock) Enqueue(namespace string, name string)
- func (mock *PodSecurityPolicyControllerMock) EnqueueCalls() []struct{ ... }
- func (mock *PodSecurityPolicyControllerMock) Generic() controller.GenericController
- func (mock *PodSecurityPolicyControllerMock) GenericCalls() []struct{}
- func (mock *PodSecurityPolicyControllerMock) Informer() cache.SharedIndexInformer
- func (mock *PodSecurityPolicyControllerMock) InformerCalls() []struct{}
- func (mock *PodSecurityPolicyControllerMock) Lister() v1beta1a.PodSecurityPolicyLister
- func (mock *PodSecurityPolicyControllerMock) ListerCalls() []struct{}
- func (mock *PodSecurityPolicyControllerMock) Start(ctx context.Context, threadiness int) error
- func (mock *PodSecurityPolicyControllerMock) StartCalls() []struct{ ... }
- func (mock *PodSecurityPolicyControllerMock) Sync(ctx context.Context) error
- func (mock *PodSecurityPolicyControllerMock) SyncCalls() []struct{ ... }
- type PodSecurityPolicyInterfaceMock
- func (mock *PodSecurityPolicyInterfaceMock) AddClusterScopedHandler(ctx context.Context, name string, clusterName string, ...)
- func (mock *PodSecurityPolicyInterfaceMock) AddClusterScopedHandlerCalls() []struct{ ... }
- func (mock *PodSecurityPolicyInterfaceMock) AddClusterScopedLifecycle(ctx context.Context, name string, clusterName string, ...)
- func (mock *PodSecurityPolicyInterfaceMock) AddClusterScopedLifecycleCalls() []struct{ ... }
- func (mock *PodSecurityPolicyInterfaceMock) AddHandler(ctx context.Context, name string, sync v1beta1a.PodSecurityPolicyHandlerFunc)
- func (mock *PodSecurityPolicyInterfaceMock) AddHandlerCalls() []struct{ ... }
- func (mock *PodSecurityPolicyInterfaceMock) AddLifecycle(ctx context.Context, name string, ...)
- func (mock *PodSecurityPolicyInterfaceMock) AddLifecycleCalls() []struct{ ... }
- func (mock *PodSecurityPolicyInterfaceMock) Controller() v1beta1a.PodSecurityPolicyController
- func (mock *PodSecurityPolicyInterfaceMock) ControllerCalls() []struct{}
- func (mock *PodSecurityPolicyInterfaceMock) Create(in1 *v1beta1.PodSecurityPolicy) (*v1beta1.PodSecurityPolicy, error)
- func (mock *PodSecurityPolicyInterfaceMock) CreateCalls() []struct{ ... }
- func (mock *PodSecurityPolicyInterfaceMock) Delete(name string, options *v1.DeleteOptions) error
- func (mock *PodSecurityPolicyInterfaceMock) DeleteCalls() []struct{ ... }
- func (mock *PodSecurityPolicyInterfaceMock) DeleteCollection(deleteOpts *v1.DeleteOptions, listOpts v1.ListOptions) error
- func (mock *PodSecurityPolicyInterfaceMock) DeleteCollectionCalls() []struct{ ... }
- func (mock *PodSecurityPolicyInterfaceMock) DeleteNamespaced(namespace string, name string, options *v1.DeleteOptions) error
- func (mock *PodSecurityPolicyInterfaceMock) DeleteNamespacedCalls() []struct{ ... }
- func (mock *PodSecurityPolicyInterfaceMock) Get(name string, opts v1.GetOptions) (*v1beta1.PodSecurityPolicy, error)
- func (mock *PodSecurityPolicyInterfaceMock) GetCalls() []struct{ ... }
- func (mock *PodSecurityPolicyInterfaceMock) GetNamespaced(namespace string, name string, opts v1.GetOptions) (*v1beta1.PodSecurityPolicy, error)
- func (mock *PodSecurityPolicyInterfaceMock) GetNamespacedCalls() []struct{ ... }
- func (mock *PodSecurityPolicyInterfaceMock) List(opts v1.ListOptions) (*v1beta1a.PodSecurityPolicyList, error)
- func (mock *PodSecurityPolicyInterfaceMock) ListCalls() []struct{ ... }
- func (mock *PodSecurityPolicyInterfaceMock) ObjectClient() *objectclient.ObjectClient
- func (mock *PodSecurityPolicyInterfaceMock) ObjectClientCalls() []struct{}
- func (mock *PodSecurityPolicyInterfaceMock) Update(in1 *v1beta1.PodSecurityPolicy) (*v1beta1.PodSecurityPolicy, error)
- func (mock *PodSecurityPolicyInterfaceMock) UpdateCalls() []struct{ ... }
- func (mock *PodSecurityPolicyInterfaceMock) Watch(opts v1.ListOptions) (watch.Interface, error)
- func (mock *PodSecurityPolicyInterfaceMock) WatchCalls() []struct{ ... }
- type PodSecurityPolicyListerMock
- func (mock *PodSecurityPolicyListerMock) Get(namespace string, name string) (*v1beta1.PodSecurityPolicy, error)
- func (mock *PodSecurityPolicyListerMock) GetCalls() []struct{ ... }
- func (mock *PodSecurityPolicyListerMock) List(namespace string, selector labels.Selector) ([]*v1beta1.PodSecurityPolicy, error)
- func (mock *PodSecurityPolicyListerMock) ListCalls() []struct{ ... }
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IngressControllerMock ¶
type IngressControllerMock struct {
// AddClusterScopedHandlerFunc mocks the AddClusterScopedHandler method.
AddClusterScopedHandlerFunc func(ctx context.Context, name string, clusterName string, handler v1beta1a.IngressHandlerFunc)
// AddHandlerFunc mocks the AddHandler method.
AddHandlerFunc func(ctx context.Context, name string, handler v1beta1a.IngressHandlerFunc)
// EnqueueFunc mocks the Enqueue method.
EnqueueFunc func(namespace string, name string)
// GenericFunc mocks the Generic method.
GenericFunc func() controller.GenericController
// InformerFunc mocks the Informer method.
InformerFunc func() cache.SharedIndexInformer
// ListerFunc mocks the Lister method.
ListerFunc func() v1beta1a.IngressLister
// StartFunc mocks the Start method.
StartFunc func(ctx context.Context, threadiness int) error
// SyncFunc mocks the Sync method.
SyncFunc func(ctx context.Context) error
// contains filtered or unexported fields
}
IngressControllerMock is a mock implementation of IngressController.
func TestSomethingThatUsesIngressController(t *testing.T) {
// make and configure a mocked IngressController
mockedIngressController := &IngressControllerMock{
AddClusterScopedHandlerFunc: func(ctx context.Context, name string, clusterName string, handler v1beta1a.IngressHandlerFunc) {
panic("mock out the AddClusterScopedHandler method")
},
AddHandlerFunc: func(ctx context.Context, name string, handler v1beta1a.IngressHandlerFunc) {
panic("mock out the AddHandler method")
},
EnqueueFunc: func(namespace string, name string) {
panic("mock out the Enqueue method")
},
GenericFunc: func() controller.GenericController {
panic("mock out the Generic method")
},
InformerFunc: func() cache.SharedIndexInformer {
panic("mock out the Informer method")
},
ListerFunc: func() v1beta1a.IngressLister {
panic("mock out the Lister method")
},
StartFunc: func(ctx context.Context, threadiness int) error {
panic("mock out the Start method")
},
SyncFunc: func(ctx context.Context) error {
panic("mock out the Sync method")
},
}
// use mockedIngressController in code that requires IngressController
// and then make assertions.
}
func (*IngressControllerMock) AddClusterScopedHandler ¶
func (mock *IngressControllerMock) AddClusterScopedHandler(ctx context.Context, name string, clusterName string, handler v1beta1a.IngressHandlerFunc)
AddClusterScopedHandler calls AddClusterScopedHandlerFunc.
func (*IngressControllerMock) AddClusterScopedHandlerCalls ¶
func (mock *IngressControllerMock) AddClusterScopedHandlerCalls() []struct { Ctx context.Context Name string ClusterName string Handler v1beta1a.IngressHandlerFunc }
AddClusterScopedHandlerCalls gets all the calls that were made to AddClusterScopedHandler. Check the length with:
len(mockedIngressController.AddClusterScopedHandlerCalls())
func (*IngressControllerMock) AddHandler ¶
func (mock *IngressControllerMock) AddHandler(ctx context.Context, name string, handler v1beta1a.IngressHandlerFunc)
AddHandler calls AddHandlerFunc.
func (*IngressControllerMock) AddHandlerCalls ¶
func (mock *IngressControllerMock) AddHandlerCalls() []struct { Ctx context.Context Name string Handler v1beta1a.IngressHandlerFunc }
AddHandlerCalls gets all the calls that were made to AddHandler. Check the length with:
len(mockedIngressController.AddHandlerCalls())
func (*IngressControllerMock) Enqueue ¶
func (mock *IngressControllerMock) Enqueue(namespace string, name string)
Enqueue calls EnqueueFunc.
func (*IngressControllerMock) EnqueueCalls ¶
func (mock *IngressControllerMock) EnqueueCalls() []struct { Namespace string Name string }
EnqueueCalls gets all the calls that were made to Enqueue. Check the length with:
len(mockedIngressController.EnqueueCalls())
func (*IngressControllerMock) Generic ¶
func (mock *IngressControllerMock) Generic() controller.GenericController
Generic calls GenericFunc.
func (*IngressControllerMock) GenericCalls ¶
func (mock *IngressControllerMock) GenericCalls() []struct { }
GenericCalls gets all the calls that were made to Generic. Check the length with:
len(mockedIngressController.GenericCalls())
func (*IngressControllerMock) Informer ¶
func (mock *IngressControllerMock) Informer() cache.SharedIndexInformer
Informer calls InformerFunc.
func (*IngressControllerMock) InformerCalls ¶
func (mock *IngressControllerMock) InformerCalls() []struct { }
InformerCalls gets all the calls that were made to Informer. Check the length with:
len(mockedIngressController.InformerCalls())
func (*IngressControllerMock) Lister ¶
func (mock *IngressControllerMock) Lister() v1beta1a.IngressLister
Lister calls ListerFunc.
func (*IngressControllerMock) ListerCalls ¶
func (mock *IngressControllerMock) ListerCalls() []struct { }
ListerCalls gets all the calls that were made to Lister. Check the length with:
len(mockedIngressController.ListerCalls())
func (*IngressControllerMock) Start ¶
func (mock *IngressControllerMock) Start(ctx context.Context, threadiness int) error
Start calls StartFunc.
func (*IngressControllerMock) StartCalls ¶
func (mock *IngressControllerMock) StartCalls() []struct { Ctx context.Context Threadiness int }
StartCalls gets all the calls that were made to Start. Check the length with:
len(mockedIngressController.StartCalls())
func (*IngressControllerMock) Sync ¶
func (mock *IngressControllerMock) Sync(ctx context.Context) error
Sync calls SyncFunc.
func (*IngressControllerMock) SyncCalls ¶
func (mock *IngressControllerMock) SyncCalls() []struct { Ctx context.Context }
SyncCalls gets all the calls that were made to Sync. Check the length with:
len(mockedIngressController.SyncCalls())
type IngressInterfaceMock ¶
type IngressInterfaceMock struct {
// AddClusterScopedHandlerFunc mocks the AddClusterScopedHandler method.
AddClusterScopedHandlerFunc func(ctx context.Context, name string, clusterName string, sync v1beta1a.IngressHandlerFunc)
// AddClusterScopedLifecycleFunc mocks the AddClusterScopedLifecycle method.
AddClusterScopedLifecycleFunc func(ctx context.Context, name string, clusterName string, lifecycle v1beta1a.IngressLifecycle)
// AddHandlerFunc mocks the AddHandler method.
AddHandlerFunc func(ctx context.Context, name string, sync v1beta1a.IngressHandlerFunc)
// AddLifecycleFunc mocks the AddLifecycle method.
AddLifecycleFunc func(ctx context.Context, name string, lifecycle v1beta1a.IngressLifecycle)
// ControllerFunc mocks the Controller method.
ControllerFunc func() v1beta1a.IngressController
// CreateFunc mocks the Create method.
CreateFunc func(in1 *v1beta1.Ingress) (*v1beta1.Ingress, error)
// DeleteFunc mocks the Delete method.
DeleteFunc func(name string, options *v1.DeleteOptions) error
// DeleteCollectionFunc mocks the DeleteCollection method.
DeleteCollectionFunc func(deleteOpts *v1.DeleteOptions, listOpts v1.ListOptions) error
// DeleteNamespacedFunc mocks the DeleteNamespaced method.
DeleteNamespacedFunc func(namespace string, name string, options *v1.DeleteOptions) error
// GetFunc mocks the Get method.
GetFunc func(name string, opts v1.GetOptions) (*v1beta1.Ingress, error)
// GetNamespacedFunc mocks the GetNamespaced method.
GetNamespacedFunc func(namespace string, name string, opts v1.GetOptions) (*v1beta1.Ingress, error)
// ListFunc mocks the List method.
ListFunc func(opts v1.ListOptions) (*v1beta1a.IngressList, error)
// ObjectClientFunc mocks the ObjectClient method.
ObjectClientFunc func() *objectclient.ObjectClient
// UpdateFunc mocks the Update method.
UpdateFunc func(in1 *v1beta1.Ingress) (*v1beta1.Ingress, error)
// WatchFunc mocks the Watch method.
WatchFunc func(opts v1.ListOptions) (watch.Interface, error)
// contains filtered or unexported fields
}
IngressInterfaceMock is a mock implementation of IngressInterface.
func TestSomethingThatUsesIngressInterface(t *testing.T) {
// make and configure a mocked IngressInterface
mockedIngressInterface := &IngressInterfaceMock{
AddClusterScopedHandlerFunc: func(ctx context.Context, name string, clusterName string, sync v1beta1a.IngressHandlerFunc) {
panic("mock out the AddClusterScopedHandler method")
},
AddClusterScopedLifecycleFunc: func(ctx context.Context, name string, clusterName string, lifecycle v1beta1a.IngressLifecycle) {
panic("mock out the AddClusterScopedLifecycle method")
},
AddHandlerFunc: func(ctx context.Context, name string, sync v1beta1a.IngressHandlerFunc) {
panic("mock out the AddHandler method")
},
AddLifecycleFunc: func(ctx context.Context, name string, lifecycle v1beta1a.IngressLifecycle) {
panic("mock out the AddLifecycle method")
},
ControllerFunc: func() v1beta1a.IngressController {
panic("mock out the Controller method")
},
CreateFunc: func(in1 *v1beta1.Ingress) (*v1beta1.Ingress, error) {
panic("mock out the Create method")
},
DeleteFunc: func(name string, options *v1.DeleteOptions) error {
panic("mock out the Delete method")
},
DeleteCollectionFunc: func(deleteOpts *v1.DeleteOptions, listOpts v1.ListOptions) error {
panic("mock out the DeleteCollection method")
},
DeleteNamespacedFunc: func(namespace string, name string, options *v1.DeleteOptions) error {
panic("mock out the DeleteNamespaced method")
},
GetFunc: func(name string, opts v1.GetOptions) (*v1beta1.Ingress, error) {
panic("mock out the Get method")
},
GetNamespacedFunc: func(namespace string, name string, opts v1.GetOptions) (*v1beta1.Ingress, error) {
panic("mock out the GetNamespaced method")
},
ListFunc: func(opts v1.ListOptions) (*v1beta1a.IngressList, error) {
panic("mock out the List method")
},
ObjectClientFunc: func() *objectclient.ObjectClient {
panic("mock out the ObjectClient method")
},
UpdateFunc: func(in1 *v1beta1.Ingress) (*v1beta1.Ingress, error) {
panic("mock out the Update method")
},
WatchFunc: func(opts v1.ListOptions) (watch.Interface, error) {
panic("mock out the Watch method")
},
}
// use mockedIngressInterface in code that requires IngressInterface
// and then make assertions.
}
func (*IngressInterfaceMock) AddClusterScopedHandler ¶
func (mock *IngressInterfaceMock) AddClusterScopedHandler(ctx context.Context, name string, clusterName string, sync v1beta1a.IngressHandlerFunc)
AddClusterScopedHandler calls AddClusterScopedHandlerFunc.
func (*IngressInterfaceMock) AddClusterScopedHandlerCalls ¶
func (mock *IngressInterfaceMock) AddClusterScopedHandlerCalls() []struct { Ctx context.Context Name string ClusterName string Sync v1beta1a.IngressHandlerFunc }
AddClusterScopedHandlerCalls gets all the calls that were made to AddClusterScopedHandler. Check the length with:
len(mockedIngressInterface.AddClusterScopedHandlerCalls())
func (*IngressInterfaceMock) AddClusterScopedLifecycle ¶
func (mock *IngressInterfaceMock) AddClusterScopedLifecycle(ctx context.Context, name string, clusterName string, lifecycle v1beta1a.IngressLifecycle)
AddClusterScopedLifecycle calls AddClusterScopedLifecycleFunc.
func (*IngressInterfaceMock) AddClusterScopedLifecycleCalls ¶
func (mock *IngressInterfaceMock) AddClusterScopedLifecycleCalls() []struct { Ctx context.Context Name string ClusterName string Lifecycle v1beta1a.IngressLifecycle }
AddClusterScopedLifecycleCalls gets all the calls that were made to AddClusterScopedLifecycle. Check the length with:
len(mockedIngressInterface.AddClusterScopedLifecycleCalls())
func (*IngressInterfaceMock) AddHandler ¶
func (mock *IngressInterfaceMock) AddHandler(ctx context.Context, name string, sync v1beta1a.IngressHandlerFunc)
AddHandler calls AddHandlerFunc.
func (*IngressInterfaceMock) AddHandlerCalls ¶
func (mock *IngressInterfaceMock) AddHandlerCalls() []struct { Ctx context.Context Name string Sync v1beta1a.IngressHandlerFunc }
AddHandlerCalls gets all the calls that were made to AddHandler. Check the length with:
len(mockedIngressInterface.AddHandlerCalls())
func (*IngressInterfaceMock) AddLifecycle ¶
func (mock *IngressInterfaceMock) AddLifecycle(ctx context.Context, name string, lifecycle v1beta1a.IngressLifecycle)
AddLifecycle calls AddLifecycleFunc.
func (*IngressInterfaceMock) AddLifecycleCalls ¶
func (mock *IngressInterfaceMock) AddLifecycleCalls() []struct { Ctx context.Context Name string Lifecycle v1beta1a.IngressLifecycle }
AddLifecycleCalls gets all the calls that were made to AddLifecycle. Check the length with:
len(mockedIngressInterface.AddLifecycleCalls())
func (*IngressInterfaceMock) Controller ¶
func (mock *IngressInterfaceMock) Controller() v1beta1a.IngressController
Controller calls ControllerFunc.
func (*IngressInterfaceMock) ControllerCalls ¶
func (mock *IngressInterfaceMock) ControllerCalls() []struct { }
ControllerCalls gets all the calls that were made to Controller. Check the length with:
len(mockedIngressInterface.ControllerCalls())
func (*IngressInterfaceMock) CreateCalls ¶
func (mock *IngressInterfaceMock) CreateCalls() []struct { In1 *v1beta1.Ingress }
CreateCalls gets all the calls that were made to Create. Check the length with:
len(mockedIngressInterface.CreateCalls())
func (*IngressInterfaceMock) Delete ¶
func (mock *IngressInterfaceMock) Delete(name string, options *v1.DeleteOptions) error
Delete calls DeleteFunc.
func (*IngressInterfaceMock) DeleteCalls ¶
func (mock *IngressInterfaceMock) DeleteCalls() []struct { Name string Options *v1.DeleteOptions }
DeleteCalls gets all the calls that were made to Delete. Check the length with:
len(mockedIngressInterface.DeleteCalls())
func (*IngressInterfaceMock) DeleteCollection ¶
func (mock *IngressInterfaceMock) DeleteCollection(deleteOpts *v1.DeleteOptions, listOpts v1.ListOptions) error
DeleteCollection calls DeleteCollectionFunc.
func (*IngressInterfaceMock) DeleteCollectionCalls ¶
func (mock *IngressInterfaceMock) DeleteCollectionCalls() []struct { DeleteOpts *v1.DeleteOptions ListOpts v1.ListOptions }
DeleteCollectionCalls gets all the calls that were made to DeleteCollection. Check the length with:
len(mockedIngressInterface.DeleteCollectionCalls())
func (*IngressInterfaceMock) DeleteNamespaced ¶
func (mock *IngressInterfaceMock) DeleteNamespaced(namespace string, name string, options *v1.DeleteOptions) error
DeleteNamespaced calls DeleteNamespacedFunc.
func (*IngressInterfaceMock) DeleteNamespacedCalls ¶
func (mock *IngressInterfaceMock) DeleteNamespacedCalls() []struct { Namespace string Name string Options *v1.DeleteOptions }
DeleteNamespacedCalls gets all the calls that were made to DeleteNamespaced. Check the length with:
len(mockedIngressInterface.DeleteNamespacedCalls())
func (*IngressInterfaceMock) Get ¶
func (mock *IngressInterfaceMock) Get(name string, opts v1.GetOptions) (*v1beta1.Ingress, error)
Get calls GetFunc.
func (*IngressInterfaceMock) GetCalls ¶
func (mock *IngressInterfaceMock) GetCalls() []struct { Name string Opts v1.GetOptions }
GetCalls gets all the calls that were made to Get. Check the length with:
len(mockedIngressInterface.GetCalls())
func (*IngressInterfaceMock) GetNamespaced ¶
func (mock *IngressInterfaceMock) GetNamespaced(namespace string, name string, opts v1.GetOptions) (*v1beta1.Ingress, error)
GetNamespaced calls GetNamespacedFunc.
func (*IngressInterfaceMock) GetNamespacedCalls ¶
func (mock *IngressInterfaceMock) GetNamespacedCalls() []struct { Namespace string Name string Opts v1.GetOptions }
GetNamespacedCalls gets all the calls that were made to GetNamespaced. Check the length with:
len(mockedIngressInterface.GetNamespacedCalls())
func (*IngressInterfaceMock) List ¶
func (mock *IngressInterfaceMock) List(opts v1.ListOptions) (*v1beta1a.IngressList, error)
List calls ListFunc.
func (*IngressInterfaceMock) ListCalls ¶
func (mock *IngressInterfaceMock) ListCalls() []struct { Opts v1.ListOptions }
ListCalls gets all the calls that were made to List. Check the length with:
len(mockedIngressInterface.ListCalls())
func (*IngressInterfaceMock) ObjectClient ¶
func (mock *IngressInterfaceMock) ObjectClient() *objectclient.ObjectClient
ObjectClient calls ObjectClientFunc.
func (*IngressInterfaceMock) ObjectClientCalls ¶
func (mock *IngressInterfaceMock) ObjectClientCalls() []struct { }
ObjectClientCalls gets all the calls that were made to ObjectClient. Check the length with:
len(mockedIngressInterface.ObjectClientCalls())
func (*IngressInterfaceMock) UpdateCalls ¶
func (mock *IngressInterfaceMock) UpdateCalls() []struct { In1 *v1beta1.Ingress }
UpdateCalls gets all the calls that were made to Update. Check the length with:
len(mockedIngressInterface.UpdateCalls())
func (*IngressInterfaceMock) Watch ¶
func (mock *IngressInterfaceMock) Watch(opts v1.ListOptions) (watch.Interface, error)
Watch calls WatchFunc.
func (*IngressInterfaceMock) WatchCalls ¶
func (mock *IngressInterfaceMock) WatchCalls() []struct { Opts v1.ListOptions }
WatchCalls gets all the calls that were made to Watch. Check the length with:
len(mockedIngressInterface.WatchCalls())
type IngressListerMock ¶
type IngressListerMock struct {
// GetFunc mocks the Get method.
GetFunc func(namespace string, name string) (*v1beta1.Ingress, error)
// ListFunc mocks the List method.
ListFunc func(namespace string, selector labels.Selector) ([]*v1beta1.Ingress, error)
// contains filtered or unexported fields
}
IngressListerMock is a mock implementation of IngressLister.
func TestSomethingThatUsesIngressLister(t *testing.T) {
// make and configure a mocked IngressLister
mockedIngressLister := &IngressListerMock{
GetFunc: func(namespace string, name string) (*v1beta1.Ingress, error) {
panic("mock out the Get method")
},
ListFunc: func(namespace string, selector labels.Selector) ([]*v1beta1.Ingress, error) {
panic("mock out the List method")
},
}
// use mockedIngressLister in code that requires IngressLister
// and then make assertions.
}
func (*IngressListerMock) GetCalls ¶
func (mock *IngressListerMock) GetCalls() []struct { Namespace string Name string }
GetCalls gets all the calls that were made to Get. Check the length with:
len(mockedIngressLister.GetCalls())
type IngressesGetterMock ¶
type IngressesGetterMock struct {
// IngressesFunc mocks the Ingresses method.
IngressesFunc func(namespace string) v1beta1a.IngressInterface
// contains filtered or unexported fields
}
IngressesGetterMock is a mock implementation of IngressesGetter.
func TestSomethingThatUsesIngressesGetter(t *testing.T) {
// make and configure a mocked IngressesGetter
mockedIngressesGetter := &IngressesGetterMock{
IngressesFunc: func(namespace string) v1beta1a.IngressInterface {
panic("mock out the Ingresses method")
},
}
// use mockedIngressesGetter in code that requires IngressesGetter
// and then make assertions.
}
func (*IngressesGetterMock) Ingresses ¶
func (mock *IngressesGetterMock) Ingresses(namespace string) v1beta1a.IngressInterface
Ingresses calls IngressesFunc.
func (*IngressesGetterMock) IngressesCalls ¶
func (mock *IngressesGetterMock) IngressesCalls() []struct { Namespace string }
IngressesCalls gets all the calls that were made to Ingresses. Check the length with:
len(mockedIngressesGetter.IngressesCalls())
type PodSecurityPoliciesGetterMock ¶
type PodSecurityPoliciesGetterMock struct {
// PodSecurityPoliciesFunc mocks the PodSecurityPolicies method.
PodSecurityPoliciesFunc func(namespace string) v1beta1a.PodSecurityPolicyInterface
// contains filtered or unexported fields
}
PodSecurityPoliciesGetterMock is a mock implementation of PodSecurityPoliciesGetter.
func TestSomethingThatUsesPodSecurityPoliciesGetter(t *testing.T) {
// make and configure a mocked PodSecurityPoliciesGetter
mockedPodSecurityPoliciesGetter := &PodSecurityPoliciesGetterMock{
PodSecurityPoliciesFunc: func(namespace string) v1beta1a.PodSecurityPolicyInterface {
panic("mock out the PodSecurityPolicies method")
},
}
// use mockedPodSecurityPoliciesGetter in code that requires PodSecurityPoliciesGetter
// and then make assertions.
}
func (*PodSecurityPoliciesGetterMock) PodSecurityPolicies ¶
func (mock *PodSecurityPoliciesGetterMock) PodSecurityPolicies(namespace string) v1beta1a.PodSecurityPolicyInterface
PodSecurityPolicies calls PodSecurityPoliciesFunc.
func (*PodSecurityPoliciesGetterMock) PodSecurityPoliciesCalls ¶
func (mock *PodSecurityPoliciesGetterMock) PodSecurityPoliciesCalls() []struct { Namespace string }
PodSecurityPoliciesCalls gets all the calls that were made to PodSecurityPolicies. Check the length with:
len(mockedPodSecurityPoliciesGetter.PodSecurityPoliciesCalls())
type PodSecurityPolicyControllerMock ¶
type PodSecurityPolicyControllerMock struct {
// AddClusterScopedHandlerFunc mocks the AddClusterScopedHandler method.
AddClusterScopedHandlerFunc func(ctx context.Context, name string, clusterName string, handler v1beta1a.PodSecurityPolicyHandlerFunc)
// AddHandlerFunc mocks the AddHandler method.
AddHandlerFunc func(ctx context.Context, name string, handler v1beta1a.PodSecurityPolicyHandlerFunc)
// EnqueueFunc mocks the Enqueue method.
EnqueueFunc func(namespace string, name string)
// GenericFunc mocks the Generic method.
GenericFunc func() controller.GenericController
// InformerFunc mocks the Informer method.
InformerFunc func() cache.SharedIndexInformer
// ListerFunc mocks the Lister method.
ListerFunc func() v1beta1a.PodSecurityPolicyLister
// StartFunc mocks the Start method.
StartFunc func(ctx context.Context, threadiness int) error
// SyncFunc mocks the Sync method.
SyncFunc func(ctx context.Context) error
// contains filtered or unexported fields
}
PodSecurityPolicyControllerMock is a mock implementation of PodSecurityPolicyController.
func TestSomethingThatUsesPodSecurityPolicyController(t *testing.T) {
// make and configure a mocked PodSecurityPolicyController
mockedPodSecurityPolicyController := &PodSecurityPolicyControllerMock{
AddClusterScopedHandlerFunc: func(ctx context.Context, name string, clusterName string, handler v1beta1a.PodSecurityPolicyHandlerFunc) {
panic("mock out the AddClusterScopedHandler method")
},
AddHandlerFunc: func(ctx context.Context, name string, handler v1beta1a.PodSecurityPolicyHandlerFunc) {
panic("mock out the AddHandler method")
},
EnqueueFunc: func(namespace string, name string) {
panic("mock out the Enqueue method")
},
GenericFunc: func() controller.GenericController {
panic("mock out the Generic method")
},
InformerFunc: func() cache.SharedIndexInformer {
panic("mock out the Informer method")
},
ListerFunc: func() v1beta1a.PodSecurityPolicyLister {
panic("mock out the Lister method")
},
StartFunc: func(ctx context.Context, threadiness int) error {
panic("mock out the Start method")
},
SyncFunc: func(ctx context.Context) error {
panic("mock out the Sync method")
},
}
// use mockedPodSecurityPolicyController in code that requires PodSecurityPolicyController
// and then make assertions.
}
func (*PodSecurityPolicyControllerMock) AddClusterScopedHandler ¶
func (mock *PodSecurityPolicyControllerMock) AddClusterScopedHandler(ctx context.Context, name string, clusterName string, handler v1beta1a.PodSecurityPolicyHandlerFunc)
AddClusterScopedHandler calls AddClusterScopedHandlerFunc.
func (*PodSecurityPolicyControllerMock) AddClusterScopedHandlerCalls ¶
func (mock *PodSecurityPolicyControllerMock) AddClusterScopedHandlerCalls() []struct { Ctx context.Context Name string ClusterName string Handler v1beta1a.PodSecurityPolicyHandlerFunc }
AddClusterScopedHandlerCalls gets all the calls that were made to AddClusterScopedHandler. Check the length with:
len(mockedPodSecurityPolicyController.AddClusterScopedHandlerCalls())
func (*PodSecurityPolicyControllerMock) AddHandler ¶
func (mock *PodSecurityPolicyControllerMock) AddHandler(ctx context.Context, name string, handler v1beta1a.PodSecurityPolicyHandlerFunc)
AddHandler calls AddHandlerFunc.
func (*PodSecurityPolicyControllerMock) AddHandlerCalls ¶
func (mock *PodSecurityPolicyControllerMock) AddHandlerCalls() []struct { Ctx context.Context Name string Handler v1beta1a.PodSecurityPolicyHandlerFunc }
AddHandlerCalls gets all the calls that were made to AddHandler. Check the length with:
len(mockedPodSecurityPolicyController.AddHandlerCalls())
func (*PodSecurityPolicyControllerMock) Enqueue ¶
func (mock *PodSecurityPolicyControllerMock) Enqueue(namespace string, name string)
Enqueue calls EnqueueFunc.
func (*PodSecurityPolicyControllerMock) EnqueueCalls ¶
func (mock *PodSecurityPolicyControllerMock) EnqueueCalls() []struct { Namespace string Name string }
EnqueueCalls gets all the calls that were made to Enqueue. Check the length with:
len(mockedPodSecurityPolicyController.EnqueueCalls())
func (*PodSecurityPolicyControllerMock) Generic ¶
func (mock *PodSecurityPolicyControllerMock) Generic() controller.GenericController
Generic calls GenericFunc.
func (*PodSecurityPolicyControllerMock) GenericCalls ¶
func (mock *PodSecurityPolicyControllerMock) GenericCalls() []struct { }
GenericCalls gets all the calls that were made to Generic. Check the length with:
len(mockedPodSecurityPolicyController.GenericCalls())
func (*PodSecurityPolicyControllerMock) Informer ¶
func (mock *PodSecurityPolicyControllerMock) Informer() cache.SharedIndexInformer
Informer calls InformerFunc.
func (*PodSecurityPolicyControllerMock) InformerCalls ¶
func (mock *PodSecurityPolicyControllerMock) InformerCalls() []struct { }
InformerCalls gets all the calls that were made to Informer. Check the length with:
len(mockedPodSecurityPolicyController.InformerCalls())
func (*PodSecurityPolicyControllerMock) Lister ¶
func (mock *PodSecurityPolicyControllerMock) Lister() v1beta1a.PodSecurityPolicyLister
Lister calls ListerFunc.
func (*PodSecurityPolicyControllerMock) ListerCalls ¶
func (mock *PodSecurityPolicyControllerMock) ListerCalls() []struct { }
ListerCalls gets all the calls that were made to Lister. Check the length with:
len(mockedPodSecurityPolicyController.ListerCalls())
func (*PodSecurityPolicyControllerMock) Start ¶
func (mock *PodSecurityPolicyControllerMock) Start(ctx context.Context, threadiness int) error
Start calls StartFunc.
func (*PodSecurityPolicyControllerMock) StartCalls ¶
func (mock *PodSecurityPolicyControllerMock) StartCalls() []struct { Ctx context.Context Threadiness int }
StartCalls gets all the calls that were made to Start. Check the length with:
len(mockedPodSecurityPolicyController.StartCalls())
func (*PodSecurityPolicyControllerMock) Sync ¶
func (mock *PodSecurityPolicyControllerMock) Sync(ctx context.Context) error
Sync calls SyncFunc.
func (*PodSecurityPolicyControllerMock) SyncCalls ¶
func (mock *PodSecurityPolicyControllerMock) SyncCalls() []struct { Ctx context.Context }
SyncCalls gets all the calls that were made to Sync. Check the length with:
len(mockedPodSecurityPolicyController.SyncCalls())
type PodSecurityPolicyInterfaceMock ¶
type PodSecurityPolicyInterfaceMock struct {
// AddClusterScopedHandlerFunc mocks the AddClusterScopedHandler method.
AddClusterScopedHandlerFunc func(ctx context.Context, name string, clusterName string, sync v1beta1a.PodSecurityPolicyHandlerFunc)
// AddClusterScopedLifecycleFunc mocks the AddClusterScopedLifecycle method.
AddClusterScopedLifecycleFunc func(ctx context.Context, name string, clusterName string, lifecycle v1beta1a.PodSecurityPolicyLifecycle)
// AddHandlerFunc mocks the AddHandler method.
AddHandlerFunc func(ctx context.Context, name string, sync v1beta1a.PodSecurityPolicyHandlerFunc)
// AddLifecycleFunc mocks the AddLifecycle method.
AddLifecycleFunc func(ctx context.Context, name string, lifecycle v1beta1a.PodSecurityPolicyLifecycle)
// ControllerFunc mocks the Controller method.
ControllerFunc func() v1beta1a.PodSecurityPolicyController
// CreateFunc mocks the Create method.
CreateFunc func(in1 *v1beta1.PodSecurityPolicy) (*v1beta1.PodSecurityPolicy, error)
// DeleteFunc mocks the Delete method.
DeleteFunc func(name string, options *v1.DeleteOptions) error
// DeleteCollectionFunc mocks the DeleteCollection method.
DeleteCollectionFunc func(deleteOpts *v1.DeleteOptions, listOpts v1.ListOptions) error
// DeleteNamespacedFunc mocks the DeleteNamespaced method.
DeleteNamespacedFunc func(namespace string, name string, options *v1.DeleteOptions) error
// GetFunc mocks the Get method.
GetFunc func(name string, opts v1.GetOptions) (*v1beta1.PodSecurityPolicy, error)
// GetNamespacedFunc mocks the GetNamespaced method.
GetNamespacedFunc func(namespace string, name string, opts v1.GetOptions) (*v1beta1.PodSecurityPolicy, error)
// ListFunc mocks the List method.
ListFunc func(opts v1.ListOptions) (*v1beta1a.PodSecurityPolicyList, error)
// ObjectClientFunc mocks the ObjectClient method.
ObjectClientFunc func() *objectclient.ObjectClient
// UpdateFunc mocks the Update method.
UpdateFunc func(in1 *v1beta1.PodSecurityPolicy) (*v1beta1.PodSecurityPolicy, error)
// WatchFunc mocks the Watch method.
WatchFunc func(opts v1.ListOptions) (watch.Interface, error)
// contains filtered or unexported fields
}
PodSecurityPolicyInterfaceMock is a mock implementation of PodSecurityPolicyInterface.
func TestSomethingThatUsesPodSecurityPolicyInterface(t *testing.T) {
// make and configure a mocked PodSecurityPolicyInterface
mockedPodSecurityPolicyInterface := &PodSecurityPolicyInterfaceMock{
AddClusterScopedHandlerFunc: func(ctx context.Context, name string, clusterName string, sync v1beta1a.PodSecurityPolicyHandlerFunc) {
panic("mock out the AddClusterScopedHandler method")
},
AddClusterScopedLifecycleFunc: func(ctx context.Context, name string, clusterName string, lifecycle v1beta1a.PodSecurityPolicyLifecycle) {
panic("mock out the AddClusterScopedLifecycle method")
},
AddHandlerFunc: func(ctx context.Context, name string, sync v1beta1a.PodSecurityPolicyHandlerFunc) {
panic("mock out the AddHandler method")
},
AddLifecycleFunc: func(ctx context.Context, name string, lifecycle v1beta1a.PodSecurityPolicyLifecycle) {
panic("mock out the AddLifecycle method")
},
ControllerFunc: func() v1beta1a.PodSecurityPolicyController {
panic("mock out the Controller method")
},
CreateFunc: func(in1 *v1beta1.PodSecurityPolicy) (*v1beta1.PodSecurityPolicy, error) {
panic("mock out the Create method")
},
DeleteFunc: func(name string, options *v1.DeleteOptions) error {
panic("mock out the Delete method")
},
DeleteCollectionFunc: func(deleteOpts *v1.DeleteOptions, listOpts v1.ListOptions) error {
panic("mock out the DeleteCollection method")
},
DeleteNamespacedFunc: func(namespace string, name string, options *v1.DeleteOptions) error {
panic("mock out the DeleteNamespaced method")
},
GetFunc: func(name string, opts v1.GetOptions) (*v1beta1.PodSecurityPolicy, error) {
panic("mock out the Get method")
},
GetNamespacedFunc: func(namespace string, name string, opts v1.GetOptions) (*v1beta1.PodSecurityPolicy, error) {
panic("mock out the GetNamespaced method")
},
ListFunc: func(opts v1.ListOptions) (*v1beta1a.PodSecurityPolicyList, error) {
panic("mock out the List method")
},
ObjectClientFunc: func() *objectclient.ObjectClient {
panic("mock out the ObjectClient method")
},
UpdateFunc: func(in1 *v1beta1.PodSecurityPolicy) (*v1beta1.PodSecurityPolicy, error) {
panic("mock out the Update method")
},
WatchFunc: func(opts v1.ListOptions) (watch.Interface, error) {
panic("mock out the Watch method")
},
}
// use mockedPodSecurityPolicyInterface in code that requires PodSecurityPolicyInterface
// and then make assertions.
}
func (*PodSecurityPolicyInterfaceMock) AddClusterScopedHandler ¶
func (mock *PodSecurityPolicyInterfaceMock) AddClusterScopedHandler(ctx context.Context, name string, clusterName string, sync v1beta1a.PodSecurityPolicyHandlerFunc)
AddClusterScopedHandler calls AddClusterScopedHandlerFunc.
func (*PodSecurityPolicyInterfaceMock) AddClusterScopedHandlerCalls ¶
func (mock *PodSecurityPolicyInterfaceMock) AddClusterScopedHandlerCalls() []struct { Ctx context.Context Name string ClusterName string Sync v1beta1a.PodSecurityPolicyHandlerFunc }
AddClusterScopedHandlerCalls gets all the calls that were made to AddClusterScopedHandler. Check the length with:
len(mockedPodSecurityPolicyInterface.AddClusterScopedHandlerCalls())
func (*PodSecurityPolicyInterfaceMock) AddClusterScopedLifecycle ¶
func (mock *PodSecurityPolicyInterfaceMock) AddClusterScopedLifecycle(ctx context.Context, name string, clusterName string, lifecycle v1beta1a.PodSecurityPolicyLifecycle)
AddClusterScopedLifecycle calls AddClusterScopedLifecycleFunc.
func (*PodSecurityPolicyInterfaceMock) AddClusterScopedLifecycleCalls ¶
func (mock *PodSecurityPolicyInterfaceMock) AddClusterScopedLifecycleCalls() []struct { Ctx context.Context Name string ClusterName string Lifecycle v1beta1a.PodSecurityPolicyLifecycle }
AddClusterScopedLifecycleCalls gets all the calls that were made to AddClusterScopedLifecycle. Check the length with:
len(mockedPodSecurityPolicyInterface.AddClusterScopedLifecycleCalls())
func (*PodSecurityPolicyInterfaceMock) AddHandler ¶
func (mock *PodSecurityPolicyInterfaceMock) AddHandler(ctx context.Context, name string, sync v1beta1a.PodSecurityPolicyHandlerFunc)
AddHandler calls AddHandlerFunc.
func (*PodSecurityPolicyInterfaceMock) AddHandlerCalls ¶
func (mock *PodSecurityPolicyInterfaceMock) AddHandlerCalls() []struct { Ctx context.Context Name string Sync v1beta1a.PodSecurityPolicyHandlerFunc }
AddHandlerCalls gets all the calls that were made to AddHandler. Check the length with:
len(mockedPodSecurityPolicyInterface.AddHandlerCalls())
func (*PodSecurityPolicyInterfaceMock) AddLifecycle ¶
func (mock *PodSecurityPolicyInterfaceMock) AddLifecycle(ctx context.Context, name string, lifecycle v1beta1a.PodSecurityPolicyLifecycle)
AddLifecycle calls AddLifecycleFunc.
func (*PodSecurityPolicyInterfaceMock) AddLifecycleCalls ¶
func (mock *PodSecurityPolicyInterfaceMock) AddLifecycleCalls() []struct { Ctx context.Context Name string Lifecycle v1beta1a.PodSecurityPolicyLifecycle }
AddLifecycleCalls gets all the calls that were made to AddLifecycle. Check the length with:
len(mockedPodSecurityPolicyInterface.AddLifecycleCalls())
func (*PodSecurityPolicyInterfaceMock) Controller ¶
func (mock *PodSecurityPolicyInterfaceMock) Controller() v1beta1a.PodSecurityPolicyController
Controller calls ControllerFunc.
func (*PodSecurityPolicyInterfaceMock) ControllerCalls ¶
func (mock *PodSecurityPolicyInterfaceMock) ControllerCalls() []struct { }
ControllerCalls gets all the calls that were made to Controller. Check the length with:
len(mockedPodSecurityPolicyInterface.ControllerCalls())
func (*PodSecurityPolicyInterfaceMock) Create ¶
func (mock *PodSecurityPolicyInterfaceMock) Create(in1 *v1beta1.PodSecurityPolicy) (*v1beta1.PodSecurityPolicy, error)
Create calls CreateFunc.
func (*PodSecurityPolicyInterfaceMock) CreateCalls ¶
func (mock *PodSecurityPolicyInterfaceMock) CreateCalls() []struct { In1 *v1beta1.PodSecurityPolicy }
CreateCalls gets all the calls that were made to Create. Check the length with:
len(mockedPodSecurityPolicyInterface.CreateCalls())
func (*PodSecurityPolicyInterfaceMock) Delete ¶
func (mock *PodSecurityPolicyInterfaceMock) Delete(name string, options *v1.DeleteOptions) error
Delete calls DeleteFunc.
func (*PodSecurityPolicyInterfaceMock) DeleteCalls ¶
func (mock *PodSecurityPolicyInterfaceMock) DeleteCalls() []struct { Name string Options *v1.DeleteOptions }
DeleteCalls gets all the calls that were made to Delete. Check the length with:
len(mockedPodSecurityPolicyInterface.DeleteCalls())
func (*PodSecurityPolicyInterfaceMock) DeleteCollection ¶
func (mock *PodSecurityPolicyInterfaceMock) DeleteCollection(deleteOpts *v1.DeleteOptions, listOpts v1.ListOptions) error
DeleteCollection calls DeleteCollectionFunc.
func (*PodSecurityPolicyInterfaceMock) DeleteCollectionCalls ¶
func (mock *PodSecurityPolicyInterfaceMock) DeleteCollectionCalls() []struct { DeleteOpts *v1.DeleteOptions ListOpts v1.ListOptions }
DeleteCollectionCalls gets all the calls that were made to DeleteCollection. Check the length with:
len(mockedPodSecurityPolicyInterface.DeleteCollectionCalls())
func (*PodSecurityPolicyInterfaceMock) DeleteNamespaced ¶
func (mock *PodSecurityPolicyInterfaceMock) DeleteNamespaced(namespace string, name string, options *v1.DeleteOptions) error
DeleteNamespaced calls DeleteNamespacedFunc.
func (*PodSecurityPolicyInterfaceMock) DeleteNamespacedCalls ¶
func (mock *PodSecurityPolicyInterfaceMock) DeleteNamespacedCalls() []struct { Namespace string Name string Options *v1.DeleteOptions }
DeleteNamespacedCalls gets all the calls that were made to DeleteNamespaced. Check the length with:
len(mockedPodSecurityPolicyInterface.DeleteNamespacedCalls())
func (*PodSecurityPolicyInterfaceMock) Get ¶
func (mock *PodSecurityPolicyInterfaceMock) Get(name string, opts v1.GetOptions) (*v1beta1.PodSecurityPolicy, error)
Get calls GetFunc.
func (*PodSecurityPolicyInterfaceMock) GetCalls ¶
func (mock *PodSecurityPolicyInterfaceMock) GetCalls() []struct { Name string Opts v1.GetOptions }
GetCalls gets all the calls that were made to Get. Check the length with:
len(mockedPodSecurityPolicyInterface.GetCalls())
func (*PodSecurityPolicyInterfaceMock) GetNamespaced ¶
func (mock *PodSecurityPolicyInterfaceMock) GetNamespaced(namespace string, name string, opts v1.GetOptions) (*v1beta1.PodSecurityPolicy, error)
GetNamespaced calls GetNamespacedFunc.
func (*PodSecurityPolicyInterfaceMock) GetNamespacedCalls ¶
func (mock *PodSecurityPolicyInterfaceMock) GetNamespacedCalls() []struct { Namespace string Name string Opts v1.GetOptions }
GetNamespacedCalls gets all the calls that were made to GetNamespaced. Check the length with:
len(mockedPodSecurityPolicyInterface.GetNamespacedCalls())
func (*PodSecurityPolicyInterfaceMock) List ¶
func (mock *PodSecurityPolicyInterfaceMock) List(opts v1.ListOptions) (*v1beta1a.PodSecurityPolicyList, error)
List calls ListFunc.
func (*PodSecurityPolicyInterfaceMock) ListCalls ¶
func (mock *PodSecurityPolicyInterfaceMock) ListCalls() []struct { Opts v1.ListOptions }
ListCalls gets all the calls that were made to List. Check the length with:
len(mockedPodSecurityPolicyInterface.ListCalls())
func (*PodSecurityPolicyInterfaceMock) ObjectClient ¶
func (mock *PodSecurityPolicyInterfaceMock) ObjectClient() *objectclient.ObjectClient
ObjectClient calls ObjectClientFunc.
func (*PodSecurityPolicyInterfaceMock) ObjectClientCalls ¶
func (mock *PodSecurityPolicyInterfaceMock) ObjectClientCalls() []struct { }
ObjectClientCalls gets all the calls that were made to ObjectClient. Check the length with:
len(mockedPodSecurityPolicyInterface.ObjectClientCalls())
func (*PodSecurityPolicyInterfaceMock) Update ¶
func (mock *PodSecurityPolicyInterfaceMock) Update(in1 *v1beta1.PodSecurityPolicy) (*v1beta1.PodSecurityPolicy, error)
Update calls UpdateFunc.
func (*PodSecurityPolicyInterfaceMock) UpdateCalls ¶
func (mock *PodSecurityPolicyInterfaceMock) UpdateCalls() []struct { In1 *v1beta1.PodSecurityPolicy }
UpdateCalls gets all the calls that were made to Update. Check the length with:
len(mockedPodSecurityPolicyInterface.UpdateCalls())
func (*PodSecurityPolicyInterfaceMock) Watch ¶
func (mock *PodSecurityPolicyInterfaceMock) Watch(opts v1.ListOptions) (watch.Interface, error)
Watch calls WatchFunc.
func (*PodSecurityPolicyInterfaceMock) WatchCalls ¶
func (mock *PodSecurityPolicyInterfaceMock) WatchCalls() []struct { Opts v1.ListOptions }
WatchCalls gets all the calls that were made to Watch. Check the length with:
len(mockedPodSecurityPolicyInterface.WatchCalls())
type PodSecurityPolicyListerMock ¶
type PodSecurityPolicyListerMock struct {
// GetFunc mocks the Get method.
GetFunc func(namespace string, name string) (*v1beta1.PodSecurityPolicy, error)
// ListFunc mocks the List method.
ListFunc func(namespace string, selector labels.Selector) ([]*v1beta1.PodSecurityPolicy, error)
// contains filtered or unexported fields
}
PodSecurityPolicyListerMock is a mock implementation of PodSecurityPolicyLister.
func TestSomethingThatUsesPodSecurityPolicyLister(t *testing.T) {
// make and configure a mocked PodSecurityPolicyLister
mockedPodSecurityPolicyLister := &PodSecurityPolicyListerMock{
GetFunc: func(namespace string, name string) (*v1beta1.PodSecurityPolicy, error) {
panic("mock out the Get method")
},
ListFunc: func(namespace string, selector labels.Selector) ([]*v1beta1.PodSecurityPolicy, error) {
panic("mock out the List method")
},
}
// use mockedPodSecurityPolicyLister in code that requires PodSecurityPolicyLister
// and then make assertions.
}
func (*PodSecurityPolicyListerMock) Get ¶
func (mock *PodSecurityPolicyListerMock) Get(namespace string, name string) (*v1beta1.PodSecurityPolicy, error)
Get calls GetFunc.
func (*PodSecurityPolicyListerMock) GetCalls ¶
func (mock *PodSecurityPolicyListerMock) GetCalls() []struct { Namespace string Name string }
GetCalls gets all the calls that were made to Get. Check the length with:
len(mockedPodSecurityPolicyLister.GetCalls())
func (*PodSecurityPolicyListerMock) List ¶
func (mock *PodSecurityPolicyListerMock) List(namespace string, selector labels.Selector) ([]*v1beta1.PodSecurityPolicy, error)
List calls ListFunc.