Documentation
¶
Index ¶
- Constants
- Variables
- func Factory(ctx context.Context, config rest.Config) (context.Context, controller.Starter, error)
- func Kind(kind string) schema.GroupKind
- func NewNetworkPolicy(namespace, name string, obj v1.NetworkPolicy) *v1.NetworkPolicy
- func Resource(resource string) schema.GroupResource
- type Client
- type Clients
- type Interface
- type NetworkPoliciesGetter
- type NetworkPolicyChangeHandlerFunc
- type NetworkPolicyClient
- type NetworkPolicyClientCache
- type NetworkPolicyController
- type NetworkPolicyHandlerFunc
- type NetworkPolicyIndexer
- type NetworkPolicyInterface
- type NetworkPolicyLifecycle
- type NetworkPolicyList
- type NetworkPolicyLister
Constants ¶
const ( GroupName = "networking.k8s.io" Version = "v1" )
Variables ¶
var ( NetworkPolicyGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "NetworkPolicy", } NetworkPolicyResource = metav1.APIResource{ Name: "networkpolicies", SingularName: "networkpolicy", Namespaced: true, Kind: NetworkPolicyGroupVersionKind.Kind, } NetworkPolicyGroupVersionResource = schema.GroupVersionResource{ Group: GroupName, Version: Version, Resource: "networkpolicies", } )
var ( SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: Version}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func NewNetworkPolicy ¶
func NewNetworkPolicy(namespace, name string, obj v1.NetworkPolicy) *v1.NetworkPolicy
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type Client ¶
func (*Client) NetworkPolicies ¶
func (c *Client) NetworkPolicies(namespace string) NetworkPolicyInterface
func (*Client) RESTClient ¶
type Clients ¶
type Clients struct {
Interface Interface
NetworkPolicy NetworkPolicyClient
}
func ClientsFrom ¶
func NewClientsFromInterface ¶
type Interface ¶
type Interface interface {
RESTClient() rest.Interface
controller.Starter
NetworkPoliciesGetter
}
type NetworkPoliciesGetter ¶
type NetworkPoliciesGetter interface {
NetworkPolicies(namespace string) NetworkPolicyInterface
}
type NetworkPolicyClient ¶
type NetworkPolicyClient interface {
Create(*v1.NetworkPolicy) (*v1.NetworkPolicy, error)
Get(namespace, name string, opts metav1.GetOptions) (*v1.NetworkPolicy, error)
Update(*v1.NetworkPolicy) (*v1.NetworkPolicy, error)
Delete(namespace, name string, options *metav1.DeleteOptions) error
List(namespace string, opts metav1.ListOptions) (*NetworkPolicyList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Cache() NetworkPolicyClientCache
OnCreate(ctx context.Context, name string, sync NetworkPolicyChangeHandlerFunc)
OnChange(ctx context.Context, name string, sync NetworkPolicyChangeHandlerFunc)
OnRemove(ctx context.Context, name string, sync NetworkPolicyChangeHandlerFunc)
Enqueue(namespace, name string)
Generic() controller.GenericController
ObjectClient() *objectclient.ObjectClient
Interface() NetworkPolicyInterface
}
type NetworkPolicyController ¶
type NetworkPolicyController interface {
Generic() controller.GenericController
Informer() cache.SharedIndexInformer
Lister() NetworkPolicyLister
AddHandler(ctx context.Context, name string, handler NetworkPolicyHandlerFunc)
AddClusterScopedHandler(ctx context.Context, name, clusterName string, handler NetworkPolicyHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type NetworkPolicyHandlerFunc ¶
func NewNetworkPolicyLifecycleAdapter ¶
func NewNetworkPolicyLifecycleAdapter(name string, clusterScoped bool, client NetworkPolicyInterface, l NetworkPolicyLifecycle) NetworkPolicyHandlerFunc
type NetworkPolicyIndexer ¶
type NetworkPolicyInterface ¶
type NetworkPolicyInterface interface {
ObjectClient() *objectclient.ObjectClient
Create(*v1.NetworkPolicy) (*v1.NetworkPolicy, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.NetworkPolicy, error)
Get(name string, opts metav1.GetOptions) (*v1.NetworkPolicy, error)
Update(*v1.NetworkPolicy) (*v1.NetworkPolicy, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*NetworkPolicyList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() NetworkPolicyController
AddHandler(ctx context.Context, name string, sync NetworkPolicyHandlerFunc)
AddLifecycle(ctx context.Context, name string, lifecycle NetworkPolicyLifecycle)
AddClusterScopedHandler(ctx context.Context, name, clusterName string, sync NetworkPolicyHandlerFunc)
AddClusterScopedLifecycle(ctx context.Context, name, clusterName string, lifecycle NetworkPolicyLifecycle)
}
type NetworkPolicyLifecycle ¶
type NetworkPolicyList ¶
type NetworkPolicyList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.NetworkPolicy `json:"items"`
}
func (*NetworkPolicyList) DeepCopy ¶
func (in *NetworkPolicyList) DeepCopy() *NetworkPolicyList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NetworkPolicyList.
func (*NetworkPolicyList) DeepCopyInto ¶
func (in *NetworkPolicyList) DeepCopyInto(out *NetworkPolicyList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*NetworkPolicyList) DeepCopyObject ¶
func (in *NetworkPolicyList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.